@@ -13,22 +13,21 @@ import libfmp.b
 def plot_matrix_with_points(C, P=np.empty((0, 2)), color='r', marker='o', linestyle='', **kwargs):
     """Compute the cost matrix of two feature sequences
 
-    Notebook: C3/C3S2_DTWbasic.ipynb
-
     Args:
         C: Matrix to be plotted
-        P: List of index pairs, to be visualized on the matrix
-        color: The color of the line plot
+        P: List of index pairs, to be visualized on the matrix (Default value = np.empty((0, 2)))
+        color: The color of the line plot (Default value = 'r').
             See https://matplotlib.org/users/colors.html
-        marker: The marker of the line plot
+        marker: The marker of the line plot (Default value = 'o').
             See https://matplotlib.org/3.1.0/api/markers_api.html
-        linestyle: The line-style of the line plot
+        linestyle: The line-style of the line plot (Default value = '').
             See https://matplotlib.org/gallery/lines_bars_and_markers/line_styles_reference.html
-        **Kwargs: Arguments for `libfmp.b.plot_matrix`
+        **kwargs: keyword arguments for :func:`libfmp.b.b_plot.plot_matrix`
 
     Returns:
-        im: The image plot
-        line: The line plot
+        fig: Handle for figure
+        im: Handle for imshow
+        line: handle for line plot
     """
 
     fig, ax, im = libfmp.b.plot_matrix(C, **kwargs)
